push!(LOAD_PATH, "../src/")
using Documenter, MultiPrecisionArrays, DocumenterTools, DocumenterCitations

mathengine = MathJax3(Dict(:loader => Dict("load" => ["[tex]/require", "[tex]/mathtools"]),
                           :tex => Dict("inlineMath" => [["\$", "\$"], ["\\(", "\\)"]],
                                        "packages" => [
                                            "base",
                                            "ams",
                                            "autoload",
                                            "mathtools",
                                            "require",
                                        ])))

bib = CitationBibliography(
    joinpath(@__DIR__, "src", "MPArray.bib"),
    style=:numeric  # default
)


makedocs(
    sitename = "MultiPrecisionArrays.jl",
    authors = "C. T. Kelley",
    format = Documenter.HTML(prettyurls = get(ENV, "CI", nothing) == "true"),
    pages = Any[
        "Home"=>"index.md",
        "GMRES-IR" => Any["Half_1.md",], 
        "More than you want to know" => 
           Any["Details/Termination.md", "Details/Interprecision_1.md",],
        "MPArray Constructors" => 
           Any["functions/MPArray.md","functions/MPGArray.md",],
        "Factorizations"=>
          Any["functions/hlu!.md", "functions/mplu!.md", "functions/mplu.md", 
                 "functions/mpglu!.md", "functions/mpglu.md",],
        "Iteration Statistics"=>
          Any["Details/Stats.md",],
        "Solvers"=>
             Any["functions/mpgeslir.md", "functions/mpgmir.md",],
        "References" => ["References.md",],
],
; plugins=[bib]
)
deploydocs(repo = "github.com/ctkelley/MultiPrecisionArrays.jl.git")
